#
# Hrefs
#
$manMacro2a{'href'} = '\n.\\"';
$manMacro2b{'href'} = '\n';
$manMacro2c{'href'} = '';

$texiMacro2a{'href'} = '';
$texiMacro2b{'href'} = '';
$texiMacro2c{'href'} = '';

$htmlMacro2a{'href'} = '<a href="';
$htmlMacro2b{'href'} = '">';
$htmlMacro2c{'href'} = '</a>';

#
# Href Targets
#
$manMacro2a{'hypertarget'} = '\n.\\"';
$manMacro2b{'hypertarget'} = '\n';
$manMacro2c{'hypertarget'} = '';

$texiMacro2a{'hypertarget'} = '';
$texiMacro2b{'hypertarget'} = '';
$texiMacro2c{'hypertarget'} = '';

$htmlMacro2a{'hypertarget'} = '<a name="';
$htmlMacro2b{'hypertarget'} = '">';
$htmlMacro2c{'hypertarget'} = '</a>';

#
# Other
#
$manMacro{'authors'} = 'Jason Hickey \fIet. al.\fP';
$texiMacro{'authors'} = 'Jason Hickey @emph{et. al.}';
$htmlMacro{'authors'} = 'Jason Hickey <em>et. al.</em>';
